# FormanceHQ
Open, modular foundation for unique payments flows

# Introduction
This API is documented in **OpenAPI format**.

# Authentication
Formance Stack offers one forms of authentication:
  - OAuth2
OAuth2 - an open protocol to allow secure authorization in a simple
and standard method from web, mobile and desktop applications.
<SecurityDefinitions />


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1.0.20230301
- Package version: v1.0.20230301
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.formance.com](https://www.formance.com)

## Requirements.

Python &gt;&#x3D;3.7

## Migration from other generators like python and python-legacy

### Changes
1. This generator uses spec case for all (object) property names and parameter names.
    - So if the spec has a property name like camelCase, it will use camelCase rather than camel_case
    - So you will need to update how you input and read properties to use spec case
2. Endpoint parameters are stored in dictionaries to prevent collisions (explanation below)
    - So you will need to update how you pass data in to endpoints
3. Endpoint responses now include the original response, the deserialized response body, and (todo)the deserialized headers
    - So you will need to update your code to use response.body to access deserialized data
4. All validated data is instantiated in an instance that subclasses all validated Schema classes and Decimal/str/list/tuple/frozendict/NoneClass/BoolClass/bytes/io.FileIO
    - This means that you can use isinstance to check if a payload validated against a schema class
    - This means that no data will be of type None/True/False
        - ingested None will subclass NoneClass
        - ingested True will subclass BoolClass
        - ingested False will subclass BoolClass
        - So if you need to check is True/False/None, instead use instance.is_true_oapg()/.is_false_oapg()/.is_none_oapg()
5. All validated class instances are immutable except for ones based on io.File
    - This is because if properties were changed after validation, that validation would no longer apply
    - So no changing values or property values after a class has been instantiated
6. String + Number types with formats
    - String type data is stored as a string and if you need to access types based on its format like date,
    date-time, uuid, number etc then you will need to use accessor functions on the instance
    - type string + format: See .as_date_oapg, .as_datetime_oapg, .as_decimal_oapg, .as_uuid_oapg
    - type number + format: See .as_float_oapg, .as_int_oapg
    - this was done because openapi/json-schema defines constraints. string data may be type string with no format
    keyword in one schema, and include a format constraint in another schema
    - So if you need to access a string format based type, use as_date_oapg/as_datetime_oapg/as_decimal_oapg/as_uuid_oapg
    - So if you need to access a number format based type, use as_int_oapg/as_float_oapg
7. Property access on AnyType(type unset) or object(dict) schemas
    - Only required keys with valid python names are properties like .someProp and have type hints
    - All optional keys may not exist, so properties are not defined for them
    - One can access optional values with dict_instance['optionalProp'] and KeyError will be raised if it does not exist
    - Use get_item_oapg if you need a way to always get a value whether or not the key exists
        - If the key does not exist, schemas.unset is returned from calling dict_instance.get_item_oapg('optionalProp')
        - All required and optional keys have type hints for this method, and @typing.overload is used
        - A type hint is also generated for additionalProperties accessed using this method
    - So you will need to update you code to use some_instance['optionalProp'] to access optional property
    and additionalProperty values
8. The location of the api classes has changed
    - Api classes are located in your_package.apis.tags.some_api
    - This change was made to eliminate redundant code generation
    - Legacy generators generated the same endpoint twice if it had > 1 tag on it
    - This generator defines an endpoint in one class, then inherits that class to generate
      apis by tags and by paths
    - This change reduces code and allows quicker run time if you use the path apis
        - path apis are at your_package.apis.paths.some_path
    - Those apis will only load their needed models, which is less to load than all of the resources needed in a tag api
    - So you will need to update your import paths to the api classes

### Why are Oapg and _oapg used in class and method names?
Classes can have arbitrarily named properties set on them
Endpoints can have arbitrary operationId method names set
For those reasons, I use the prefix Oapg and _oapg to greatly reduce the likelihood of collisions
on protected + public classes/methods.
oapg stands for OpenApi Python Generator.

### Object property spec case
This was done because when payloads are ingested, they can be validated against N number of schemas.
If the input signature used a different property name then that has mutated the payload.
So SchemaA and SchemaB must both see the camelCase spec named variable.
Also it is possible to send in two properties, named camelCase and camel_case in the same payload.
That use case should be support so spec case is used.

### Parameter spec case
Parameters can be included in different locations including:
- query
- path
- header
- cookie

Any of those parameters could use the same parameter names, so if every parameter
was included as an endpoint parameter in a function signature, they would collide.
For that reason, each of those inputs have been separated out into separate typed dictionaries:
- query_params
- path_params
- header_params
- cookie_params

So when updating your code, you will need to pass endpoint parameters in using those
dictionaries.

### Endpoint responses
Endpoint responses have been enriched to now include more information.
Any response reom an endpoint will now include the following properties:
response: urllib3.HTTPResponse
body: typing.Union[Unset, Schema]
headers: typing.Union[Unset, TODO]
Note: response header deserialization has not yet been added


## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/formancehq/formance-sdk-python.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/formancehq/formance-sdk-python.git`)

Then import the package:
```python
import FormanceHQ
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import FormanceHQ
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import FormanceHQ
from pprint import pprint
from FormanceHQ.apis.tags import accounts_api
from FormanceHQ.model.account_response import AccountResponse
from FormanceHQ.model.accounts_cursor_response import AccountsCursorResponse
from FormanceHQ.model.error_response import ErrorResponse
from FormanceHQ.model.ledger_metadata import LedgerMetadata
# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = FormanceHQ.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure OAuth2 access token for authorization: Authorization
configuration = FormanceHQ.Configuration(
    host = "http://localhost",
    access_token = 'YOUR_ACCESS_TOKEN'
)

# Enter a context with an instance of the API client
with FormanceHQ.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = accounts_api.AccountsApi(api_client)
    ledger = "ledger001" # str | Name of the ledger.
address = "users:001" # str | Exact address of the account. It must match the following regular expressions pattern: ``` ^\\w+(:\\w+)*$ ``` 
ledger_metadata = LedgerMetadata(
        key=None,
    ) # LedgerMetadata | metadata

    try:
        # Add metadata to an account
        api_instance.add_metadata_to_account(ledgeraddressledger_metadata)
    except FormanceHQ.ApiException as e:
        print("Exception when calling AccountsApi->add_metadata_to_account: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountsApi* | [**add_metadata_to_account**](docs/apis/tags/AccountsApi.md#add_metadata_to_account) | **post** /api/ledger/{ledger}/accounts/{address}/metadata | Add metadata to an account
*AccountsApi* | [**count_accounts**](docs/apis/tags/AccountsApi.md#count_accounts) | **head** /api/ledger/{ledger}/accounts | Count the accounts from a ledger
*AccountsApi* | [**get_account**](docs/apis/tags/AccountsApi.md#get_account) | **get** /api/ledger/{ledger}/accounts/{address} | Get account by its address
*AccountsApi* | [**list_accounts**](docs/apis/tags/AccountsApi.md#list_accounts) | **get** /api/ledger/{ledger}/accounts | List accounts from a ledger
*BalancesApi* | [**get_balances**](docs/apis/tags/BalancesApi.md#get_balances) | **get** /api/ledger/{ledger}/balances | Get the balances from a ledger&#x27;s account
*BalancesApi* | [**get_balances_aggregated**](docs/apis/tags/BalancesApi.md#get_balances_aggregated) | **get** /api/ledger/{ledger}/aggregate/balances | Get the aggregated balances from selected accounts
*ClientsApi* | [**add_scope_to_client**](docs/apis/tags/ClientsApi.md#add_scope_to_client) | **put** /api/auth/clients/{clientId}/scopes/{scopeId} | Add scope to client
*ClientsApi* | [**create_client**](docs/apis/tags/ClientsApi.md#create_client) | **post** /api/auth/clients | Create client
*ClientsApi* | [**create_secret**](docs/apis/tags/ClientsApi.md#create_secret) | **post** /api/auth/clients/{clientId}/secrets | Add a secret to a client
*ClientsApi* | [**delete_client**](docs/apis/tags/ClientsApi.md#delete_client) | **delete** /api/auth/clients/{clientId} | Delete client
*ClientsApi* | [**delete_scope_from_client**](docs/apis/tags/ClientsApi.md#delete_scope_from_client) | **delete** /api/auth/clients/{clientId}/scopes/{scopeId} | Delete scope from client
*ClientsApi* | [**delete_secret**](docs/apis/tags/ClientsApi.md#delete_secret) | **delete** /api/auth/clients/{clientId}/secrets/{secretId} | Delete a secret from a client
*ClientsApi* | [**list_clients**](docs/apis/tags/ClientsApi.md#list_clients) | **get** /api/auth/clients | List clients
*ClientsApi* | [**read_client**](docs/apis/tags/ClientsApi.md#read_client) | **get** /api/auth/clients/{clientId} | Read client
*ClientsApi* | [**update_client**](docs/apis/tags/ClientsApi.md#update_client) | **put** /api/auth/clients/{clientId} | Update client
*LedgerApi* | [**get_ledger_info**](docs/apis/tags/LedgerApi.md#get_ledger_info) | **get** /api/ledger/{ledger}/_info | Get information about a ledger
*LogsApi* | [**list_logs**](docs/apis/tags/LogsApi.md#list_logs) | **get** /api/ledger/{ledger}/logs | List the logs from a ledger
*MappingApi* | [**get_mapping**](docs/apis/tags/MappingApi.md#get_mapping) | **get** /api/ledger/{ledger}/mapping | Get the mapping of a ledger
*MappingApi* | [**update_mapping**](docs/apis/tags/MappingApi.md#update_mapping) | **put** /api/ledger/{ledger}/mapping | Update the mapping of a ledger
*OrchestrationApi* | [**cancel_event**](docs/apis/tags/OrchestrationApi.md#cancel_event) | **put** /api/orchestration/instances/{instanceID}/abort | Cancel a running workflow
*OrchestrationApi* | [**create_workflow**](docs/apis/tags/OrchestrationApi.md#create_workflow) | **post** /api/orchestration/workflows | Create workflow
*OrchestrationApi* | [**get_instance**](docs/apis/tags/OrchestrationApi.md#get_instance) | **get** /api/orchestration/instances/{instanceID} | Get a workflow instance by id
*OrchestrationApi* | [**get_instance_history**](docs/apis/tags/OrchestrationApi.md#get_instance_history) | **get** /api/orchestration/instances/{instanceID}/history | Get a workflow instance history by id
*OrchestrationApi* | [**get_instance_stage_history**](docs/apis/tags/OrchestrationApi.md#get_instance_stage_history) | **get** /api/orchestration/instances/{instanceID}/stages/{number}/history | Get a workflow instance stage history
*OrchestrationApi* | [**get_workflow**](docs/apis/tags/OrchestrationApi.md#get_workflow) | **get** /api/orchestration/workflows/{flowId} | Get a flow by id
*OrchestrationApi* | [**list_instances**](docs/apis/tags/OrchestrationApi.md#list_instances) | **get** /api/orchestration/instances | List instances of a workflow
*OrchestrationApi* | [**list_workflows**](docs/apis/tags/OrchestrationApi.md#list_workflows) | **get** /api/orchestration/workflows | List registered workflows
*OrchestrationApi* | [**orchestrationget_server_info**](docs/apis/tags/OrchestrationApi.md#orchestrationget_server_info) | **get** /api/orchestration/_info | Get server info
*OrchestrationApi* | [**run_workflow**](docs/apis/tags/OrchestrationApi.md#run_workflow) | **post** /api/orchestration/workflows/{workflowID}/instances | Run workflow
*OrchestrationApi* | [**send_event**](docs/apis/tags/OrchestrationApi.md#send_event) | **post** /api/orchestration/instances/{instanceID}/events | Send an event to a running workflow
*PaymentsApi* | [**connectors_stripe_transfer**](docs/apis/tags/PaymentsApi.md#connectors_stripe_transfer) | **post** /api/payments/connectors/stripe/transfers | Transfer funds between Stripe accounts
*PaymentsApi* | [**connectors_transfer**](docs/apis/tags/PaymentsApi.md#connectors_transfer) | **post** /api/payments/connectors/{connector}/transfers | Transfer funds between Connector accounts
*PaymentsApi* | [**get_connector_task**](docs/apis/tags/PaymentsApi.md#get_connector_task) | **get** /api/payments/connectors/{connector}/tasks/{taskId} | Read a specific task of the connector
*PaymentsApi* | [**get_payment**](docs/apis/tags/PaymentsApi.md#get_payment) | **get** /api/payments/payments/{paymentId} | Get a payment
*PaymentsApi* | [**install_connector**](docs/apis/tags/PaymentsApi.md#install_connector) | **post** /api/payments/connectors/{connector} | Install a connector
*PaymentsApi* | [**list_all_connectors**](docs/apis/tags/PaymentsApi.md#list_all_connectors) | **get** /api/payments/connectors | List all installed connectors
*PaymentsApi* | [**list_configs_available_connectors**](docs/apis/tags/PaymentsApi.md#list_configs_available_connectors) | **get** /api/payments/connectors/configs | List the configs of each available connector
*PaymentsApi* | [**list_connector_tasks**](docs/apis/tags/PaymentsApi.md#list_connector_tasks) | **get** /api/payments/connectors/{connector}/tasks | List tasks from a connector
*PaymentsApi* | [**list_connectors_transfers**](docs/apis/tags/PaymentsApi.md#list_connectors_transfers) | **get** /api/payments/connectors/{connector}/transfers | List transfers and their statuses
*PaymentsApi* | [**list_payments**](docs/apis/tags/PaymentsApi.md#list_payments) | **get** /api/payments/payments | List payments
*PaymentsApi* | [**paymentslist_accounts**](docs/apis/tags/PaymentsApi.md#paymentslist_accounts) | **get** /api/payments/accounts | List accounts
*PaymentsApi* | [**read_connector_config**](docs/apis/tags/PaymentsApi.md#read_connector_config) | **get** /api/payments/connectors/{connector}/config | Read the config of a connector
*PaymentsApi* | [**reset_connector**](docs/apis/tags/PaymentsApi.md#reset_connector) | **post** /api/payments/connectors/{connector}/reset | Reset a connector
*PaymentsApi* | [**uninstall_connector**](docs/apis/tags/PaymentsApi.md#uninstall_connector) | **delete** /api/payments/connectors/{connector} | Uninstall a connector
*PaymentsApi* | [**update_metadata**](docs/apis/tags/PaymentsApi.md#update_metadata) | **patch** /api/payments/payments/{paymentId}/metadata | Update metadata
*ScopesApi* | [**add_transient_scope**](docs/apis/tags/ScopesApi.md#add_transient_scope) | **put** /api/auth/scopes/{scopeId}/transient/{transientScopeId} | Add a transient scope to a scope
*ScopesApi* | [**create_scope**](docs/apis/tags/ScopesApi.md#create_scope) | **post** /api/auth/scopes | Create scope
*ScopesApi* | [**delete_scope**](docs/apis/tags/ScopesApi.md#delete_scope) | **delete** /api/auth/scopes/{scopeId} | Delete scope
*ScopesApi* | [**delete_transient_scope**](docs/apis/tags/ScopesApi.md#delete_transient_scope) | **delete** /api/auth/scopes/{scopeId}/transient/{transientScopeId} | Delete a transient scope from a scope
*ScopesApi* | [**list_scopes**](docs/apis/tags/ScopesApi.md#list_scopes) | **get** /api/auth/scopes | List scopes
*ScopesApi* | [**read_scope**](docs/apis/tags/ScopesApi.md#read_scope) | **get** /api/auth/scopes/{scopeId} | Read scope
*ScopesApi* | [**update_scope**](docs/apis/tags/ScopesApi.md#update_scope) | **put** /api/auth/scopes/{scopeId} | Update scope
*ScriptApi* | [**run_script**](docs/apis/tags/ScriptApi.md#run_script) | **post** /api/ledger/{ledger}/script | Execute a Numscript
*SearchApi* | [**search**](docs/apis/tags/SearchApi.md#search) | **post** /api/search/ | Search
*ServerApi* | [**get_info**](docs/apis/tags/ServerApi.md#get_info) | **get** /api/ledger/_info | Show server information
*StatsApi* | [**read_stats**](docs/apis/tags/StatsApi.md#read_stats) | **get** /api/ledger/{ledger}/stats | Get statistics from a ledger
*TransactionsApi* | [**add_metadata_on_transaction**](docs/apis/tags/TransactionsApi.md#add_metadata_on_transaction) | **post** /api/ledger/{ledger}/transactions/{txid}/metadata | Set the metadata of a transaction by its ID
*TransactionsApi* | [**count_transactions**](docs/apis/tags/TransactionsApi.md#count_transactions) | **head** /api/ledger/{ledger}/transactions | Count the transactions from a ledger
*TransactionsApi* | [**create_transaction**](docs/apis/tags/TransactionsApi.md#create_transaction) | **post** /api/ledger/{ledger}/transactions | Create a new transaction to a ledger
*TransactionsApi* | [**create_transactions**](docs/apis/tags/TransactionsApi.md#create_transactions) | **post** /api/ledger/{ledger}/transactions/batch | Create a new batch of transactions to a ledger
*TransactionsApi* | [**get_transaction**](docs/apis/tags/TransactionsApi.md#get_transaction) | **get** /api/ledger/{ledger}/transactions/{txid} | Get transaction from a ledger by its ID
*TransactionsApi* | [**list_transactions**](docs/apis/tags/TransactionsApi.md#list_transactions) | **get** /api/ledger/{ledger}/transactions | List transactions from a ledger
*TransactionsApi* | [**revert_transaction**](docs/apis/tags/TransactionsApi.md#revert_transaction) | **post** /api/ledger/{ledger}/transactions/{txid}/revert | Revert a ledger transaction by its ID
*UsersApi* | [**list_users**](docs/apis/tags/UsersApi.md#list_users) | **get** /api/auth/users | List users
*UsersApi* | [**read_user**](docs/apis/tags/UsersApi.md#read_user) | **get** /api/auth/users/{userId} | Read user
*WalletsApi* | [**confirm_hold**](docs/apis/tags/WalletsApi.md#confirm_hold) | **post** /api/wallets/holds/{hold_id}/confirm | Confirm a hold
*WalletsApi* | [**create_balance**](docs/apis/tags/WalletsApi.md#create_balance) | **post** /api/wallets/wallets/{id}/balances | Create a balance
*WalletsApi* | [**create_wallet**](docs/apis/tags/WalletsApi.md#create_wallet) | **post** /api/wallets/wallets | Create a new wallet
*WalletsApi* | [**credit_wallet**](docs/apis/tags/WalletsApi.md#credit_wallet) | **post** /api/wallets/wallets/{id}/credit | Credit a wallet
*WalletsApi* | [**debit_wallet**](docs/apis/tags/WalletsApi.md#debit_wallet) | **post** /api/wallets/wallets/{id}/debit | Debit a wallet
*WalletsApi* | [**get_balance**](docs/apis/tags/WalletsApi.md#get_balance) | **get** /api/wallets/wallets/{id}/balances/{balanceName} | Get detailed balance
*WalletsApi* | [**get_hold**](docs/apis/tags/WalletsApi.md#get_hold) | **get** /api/wallets/holds/{holdID} | Get a hold
*WalletsApi* | [**get_holds**](docs/apis/tags/WalletsApi.md#get_holds) | **get** /api/wallets/holds | Get all holds for a wallet
*WalletsApi* | [**get_transactions**](docs/apis/tags/WalletsApi.md#get_transactions) | **get** /api/wallets/transactions | 
*WalletsApi* | [**get_wallet**](docs/apis/tags/WalletsApi.md#get_wallet) | **get** /api/wallets/wallets/{id} | Get a wallet
*WalletsApi* | [**list_balances**](docs/apis/tags/WalletsApi.md#list_balances) | **get** /api/wallets/wallets/{id}/balances | List balances of a wallet
*WalletsApi* | [**list_wallets**](docs/apis/tags/WalletsApi.md#list_wallets) | **get** /api/wallets/wallets | List all wallets
*WalletsApi* | [**update_wallet**](docs/apis/tags/WalletsApi.md#update_wallet) | **patch** /api/wallets/wallets/{id} | Update a wallet
*WalletsApi* | [**void_hold**](docs/apis/tags/WalletsApi.md#void_hold) | **post** /api/wallets/holds/{hold_id}/void | Cancel a hold
*WalletsApi* | [**walletsget_server_info**](docs/apis/tags/WalletsApi.md#walletsget_server_info) | **get** /api/wallets/_info | Get server info
*WebhooksApi* | [**activate_config**](docs/apis/tags/WebhooksApi.md#activate_config) | **put** /api/webhooks/configs/{id}/activate | Activate one config
*WebhooksApi* | [**change_config_secret**](docs/apis/tags/WebhooksApi.md#change_config_secret) | **put** /api/webhooks/configs/{id}/secret/change | Change the signing secret of a config
*WebhooksApi* | [**deactivate_config**](docs/apis/tags/WebhooksApi.md#deactivate_config) | **put** /api/webhooks/configs/{id}/deactivate | Deactivate one config
*WebhooksApi* | [**delete_config**](docs/apis/tags/WebhooksApi.md#delete_config) | **delete** /api/webhooks/configs/{id} | Delete one config
*WebhooksApi* | [**get_many_configs**](docs/apis/tags/WebhooksApi.md#get_many_configs) | **get** /api/webhooks/configs | Get many configs
*WebhooksApi* | [**insert_config**](docs/apis/tags/WebhooksApi.md#insert_config) | **post** /api/webhooks/configs | Insert a new config
*WebhooksApi* | [**test_config**](docs/apis/tags/WebhooksApi.md#test_config) | **get** /api/webhooks/configs/{id}/test | Test one config
*DefaultApi* | [**get_server_info**](docs/apis/tags/DefaultApi.md#get_server_info) | **get** /api/auth/_info | Get server info
*DefaultApi* | [**paymentsget_server_info**](docs/apis/tags/DefaultApi.md#paymentsget_server_info) | **get** /api/payments/_info | Get server info
*DefaultApi* | [**searchget_server_info**](docs/apis/tags/DefaultApi.md#searchget_server_info) | **get** /api/search/_info | Get server info

## Documentation For Models

 - [Account](docs/models/Account.md)
 - [AccountResponse](docs/models/AccountResponse.md)
 - [AccountWithVolumesAndBalances](docs/models/AccountWithVolumesAndBalances.md)
 - [AccountsBalances](docs/models/AccountsBalances.md)
 - [AccountsCursor](docs/models/AccountsCursor.md)
 - [AccountsCursorResponse](docs/models/AccountsCursorResponse.md)
 - [ActivityConfirmHold](docs/models/ActivityConfirmHold.md)
 - [ActivityCreateTransaction](docs/models/ActivityCreateTransaction.md)
 - [ActivityCreateTransactionOutput](docs/models/ActivityCreateTransactionOutput.md)
 - [ActivityCreditWallet](docs/models/ActivityCreditWallet.md)
 - [ActivityDebitWallet](docs/models/ActivityDebitWallet.md)
 - [ActivityDebitWalletOutput](docs/models/ActivityDebitWalletOutput.md)
 - [ActivityGetAccount](docs/models/ActivityGetAccount.md)
 - [ActivityGetAccountOutput](docs/models/ActivityGetAccountOutput.md)
 - [ActivityGetPayment](docs/models/ActivityGetPayment.md)
 - [ActivityGetPaymentOutput](docs/models/ActivityGetPaymentOutput.md)
 - [ActivityGetWallet](docs/models/ActivityGetWallet.md)
 - [ActivityGetWalletOutput](docs/models/ActivityGetWalletOutput.md)
 - [ActivityRevertTransaction](docs/models/ActivityRevertTransaction.md)
 - [ActivityRevertTransactionOutput](docs/models/ActivityRevertTransactionOutput.md)
 - [ActivityStripeTransfer](docs/models/ActivityStripeTransfer.md)
 - [ActivityVoidHold](docs/models/ActivityVoidHold.md)
 - [AggregateBalancesResponse](docs/models/AggregateBalancesResponse.md)
 - [AggregatedVolumes](docs/models/AggregatedVolumes.md)
 - [AssetHolder](docs/models/AssetHolder.md)
 - [AssetsBalances](docs/models/AssetsBalances.md)
 - [Attempt](docs/models/Attempt.md)
 - [AttemptResponse](docs/models/AttemptResponse.md)
 - [Balance](docs/models/Balance.md)
 - [BalanceWithAssets](docs/models/BalanceWithAssets.md)
 - [BalancesCursorResponse](docs/models/BalancesCursorResponse.md)
 - [BankingCircleConfig](docs/models/BankingCircleConfig.md)
 - [Client](docs/models/Client.md)
 - [ClientOptions](docs/models/ClientOptions.md)
 - [ClientSecret](docs/models/ClientSecret.md)
 - [Config](docs/models/Config.md)
 - [ConfigChangeSecret](docs/models/ConfigChangeSecret.md)
 - [ConfigInfo](docs/models/ConfigInfo.md)
 - [ConfigInfoResponse](docs/models/ConfigInfoResponse.md)
 - [ConfigResponse](docs/models/ConfigResponse.md)
 - [ConfigUser](docs/models/ConfigUser.md)
 - [ConfigsResponse](docs/models/ConfigsResponse.md)
 - [ConfirmHoldRequest](docs/models/ConfirmHoldRequest.md)
 - [Connector](docs/models/Connector.md)
 - [ConnectorConfig](docs/models/ConnectorConfig.md)
 - [ConnectorConfigResponse](docs/models/ConnectorConfigResponse.md)
 - [ConnectorsConfigsResponse](docs/models/ConnectorsConfigsResponse.md)
 - [ConnectorsResponse](docs/models/ConnectorsResponse.md)
 - [Contract](docs/models/Contract.md)
 - [CreateBalanceRequest](docs/models/CreateBalanceRequest.md)
 - [CreateBalanceResponse](docs/models/CreateBalanceResponse.md)
 - [CreateClientRequest](docs/models/CreateClientRequest.md)
 - [CreateClientResponse](docs/models/CreateClientResponse.md)
 - [CreateScopeRequest](docs/models/CreateScopeRequest.md)
 - [CreateScopeResponse](docs/models/CreateScopeResponse.md)
 - [CreateSecretRequest](docs/models/CreateSecretRequest.md)
 - [CreateSecretResponse](docs/models/CreateSecretResponse.md)
 - [CreateWalletRequest](docs/models/CreateWalletRequest.md)
 - [CreateWalletResponse](docs/models/CreateWalletResponse.md)
 - [CreateWorkflowRequest](docs/models/CreateWorkflowRequest.md)
 - [CreateWorkflowResponse](docs/models/CreateWorkflowResponse.md)
 - [CreditWalletRequest](docs/models/CreditWalletRequest.md)
 - [CurrencyCloudConfig](docs/models/CurrencyCloudConfig.md)
 - [Cursor](docs/models/Cursor.md)
 - [CursorBase](docs/models/CursorBase.md)
 - [DebitWalletRequest](docs/models/DebitWalletRequest.md)
 - [DebitWalletResponse](docs/models/DebitWalletResponse.md)
 - [DummyPayConfig](docs/models/DummyPayConfig.md)
 - [Error](docs/models/Error.md)
 - [ErrorResponse](docs/models/ErrorResponse.md)
 - [ErrorsEnum](docs/models/ErrorsEnum.md)
 - [ExpandedDebitHold](docs/models/ExpandedDebitHold.md)
 - [GetBalanceResponse](docs/models/GetBalanceResponse.md)
 - [GetHoldResponse](docs/models/GetHoldResponse.md)
 - [GetHoldsResponse](docs/models/GetHoldsResponse.md)
 - [GetTransactionsResponse](docs/models/GetTransactionsResponse.md)
 - [GetWalletResponse](docs/models/GetWalletResponse.md)
 - [GetWorkflowInstanceHistoryResponse](docs/models/GetWorkflowInstanceHistoryResponse.md)
 - [GetWorkflowInstanceHistoryStageResponse](docs/models/GetWorkflowInstanceHistoryStageResponse.md)
 - [GetWorkflowInstanceResponse](docs/models/GetWorkflowInstanceResponse.md)
 - [GetWorkflowResponse](docs/models/GetWorkflowResponse.md)
 - [Hold](docs/models/Hold.md)
 - [LedgerAccountSubject](docs/models/LedgerAccountSubject.md)
 - [LedgerInfo](docs/models/LedgerInfo.md)
 - [LedgerInfoResponse](docs/models/LedgerInfoResponse.md)
 - [LedgerMetadata](docs/models/LedgerMetadata.md)
 - [LedgerStorage](docs/models/LedgerStorage.md)
 - [ListBalancesResponse](docs/models/ListBalancesResponse.md)
 - [ListClientsResponse](docs/models/ListClientsResponse.md)
 - [ListRunsResponse](docs/models/ListRunsResponse.md)
 - [ListScopesResponse](docs/models/ListScopesResponse.md)
 - [ListUsersResponse](docs/models/ListUsersResponse.md)
 - [ListWalletsResponse](docs/models/ListWalletsResponse.md)
 - [ListWorkflowsResponse](docs/models/ListWorkflowsResponse.md)
 - [Log](docs/models/Log.md)
 - [LogsCursorResponse](docs/models/LogsCursorResponse.md)
 - [Mapping](docs/models/Mapping.md)
 - [MappingResponse](docs/models/MappingResponse.md)
 - [Metadata](docs/models/Metadata.md)
 - [MigrationInfo](docs/models/MigrationInfo.md)
 - [ModulrConfig](docs/models/ModulrConfig.md)
 - [Monetary](docs/models/Monetary.md)
 - [Payment](docs/models/Payment.md)
 - [PaymentAdjustment](docs/models/PaymentAdjustment.md)
 - [PaymentMetadata](docs/models/PaymentMetadata.md)
 - [PaymentResponse](docs/models/PaymentResponse.md)
 - [PaymentStatus](docs/models/PaymentStatus.md)
 - [PaymentsAccount](docs/models/PaymentsAccount.md)
 - [PaymentsCursor](docs/models/PaymentsCursor.md)
 - [PostTransaction](docs/models/PostTransaction.md)
 - [Posting](docs/models/Posting.md)
 - [Query](docs/models/Query.md)
 - [ReadClientResponse](docs/models/ReadClientResponse.md)
 - [ReadScopeResponse](docs/models/ReadScopeResponse.md)
 - [ReadUserResponse](docs/models/ReadUserResponse.md)
 - [ReadWorkflowResponse](docs/models/ReadWorkflowResponse.md)
 - [Response](docs/models/Response.md)
 - [RunWorkflowRequest](docs/models/RunWorkflowRequest.md)
 - [RunWorkflowResponse](docs/models/RunWorkflowResponse.md)
 - [Scope](docs/models/Scope.md)
 - [ScopeOptions](docs/models/ScopeOptions.md)
 - [Script](docs/models/Script.md)
 - [ScriptResponse](docs/models/ScriptResponse.md)
 - [Secret](docs/models/Secret.md)
 - [SecretOptions](docs/models/SecretOptions.md)
 - [ServerInfo](docs/models/ServerInfo.md)
 - [Stage](docs/models/Stage.md)
 - [StageDelay](docs/models/StageDelay.md)
 - [StageSend](docs/models/StageSend.md)
 - [StageSendDestination](docs/models/StageSendDestination.md)
 - [StageSendDestinationAccount](docs/models/StageSendDestinationAccount.md)
 - [StageSendDestinationPayment](docs/models/StageSendDestinationPayment.md)
 - [StageSendDestinationWallet](docs/models/StageSendDestinationWallet.md)
 - [StageSendSource](docs/models/StageSendSource.md)
 - [StageSendSourceAccount](docs/models/StageSendSourceAccount.md)
 - [StageSendSourcePayment](docs/models/StageSendSourcePayment.md)
 - [StageSendSourceWallet](docs/models/StageSendSourceWallet.md)
 - [StageStatus](docs/models/StageStatus.md)
 - [StageWaitEvent](docs/models/StageWaitEvent.md)
 - [Stats](docs/models/Stats.md)
 - [StatsResponse](docs/models/StatsResponse.md)
 - [StripeConfig](docs/models/StripeConfig.md)
 - [StripeTransferRequest](docs/models/StripeTransferRequest.md)
 - [Subject](docs/models/Subject.md)
 - [TaskBankingCircle](docs/models/TaskBankingCircle.md)
 - [TaskBase](docs/models/TaskBase.md)
 - [TaskCurrencyCloud](docs/models/TaskCurrencyCloud.md)
 - [TaskDummyPay](docs/models/TaskDummyPay.md)
 - [TaskModulr](docs/models/TaskModulr.md)
 - [TaskResponse](docs/models/TaskResponse.md)
 - [TaskStripe](docs/models/TaskStripe.md)
 - [TaskWise](docs/models/TaskWise.md)
 - [TasksCursor](docs/models/TasksCursor.md)
 - [Transaction](docs/models/Transaction.md)
 - [TransactionData](docs/models/TransactionData.md)
 - [TransactionResponse](docs/models/TransactionResponse.md)
 - [Transactions](docs/models/Transactions.md)
 - [TransactionsCursorResponse](docs/models/TransactionsCursorResponse.md)
 - [TransactionsResponse](docs/models/TransactionsResponse.md)
 - [TransferRequest](docs/models/TransferRequest.md)
 - [TransferResponse](docs/models/TransferResponse.md)
 - [TransfersResponse](docs/models/TransfersResponse.md)
 - [UpdateClientRequest](docs/models/UpdateClientRequest.md)
 - [UpdateClientResponse](docs/models/UpdateClientResponse.md)
 - [UpdateScopeRequest](docs/models/UpdateScopeRequest.md)
 - [UpdateScopeResponse](docs/models/UpdateScopeResponse.md)
 - [User](docs/models/User.md)
 - [Volume](docs/models/Volume.md)
 - [Volumes](docs/models/Volumes.md)
 - [Wallet](docs/models/Wallet.md)
 - [WalletSubject](docs/models/WalletSubject.md)
 - [WalletWithBalances](docs/models/WalletWithBalances.md)
 - [WalletsAggregatedVolumes](docs/models/WalletsAggregatedVolumes.md)
 - [WalletsCursor](docs/models/WalletsCursor.md)
 - [WalletsErrorResponse](docs/models/WalletsErrorResponse.md)
 - [WalletsTransaction](docs/models/WalletsTransaction.md)
 - [WalletsVolume](docs/models/WalletsVolume.md)
 - [WalletsVolumes](docs/models/WalletsVolumes.md)
 - [WebhooksConfig](docs/models/WebhooksConfig.md)
 - [WiseConfig](docs/models/WiseConfig.md)
 - [Workflow](docs/models/Workflow.md)
 - [WorkflowConfig](docs/models/WorkflowConfig.md)
 - [WorkflowInstance](docs/models/WorkflowInstance.md)
 - [WorkflowInstanceHistory](docs/models/WorkflowInstanceHistory.md)
 - [WorkflowInstanceHistoryList](docs/models/WorkflowInstanceHistoryList.md)
 - [WorkflowInstanceHistoryStage](docs/models/WorkflowInstanceHistoryStage.md)
 - [WorkflowInstanceHistoryStageInput](docs/models/WorkflowInstanceHistoryStageInput.md)
 - [WorkflowInstanceHistoryStageList](docs/models/WorkflowInstanceHistoryStageList.md)
 - [WorkflowInstanceHistoryStageOutput](docs/models/WorkflowInstanceHistoryStageOutput.md)

## Documentation For Authorization

 Authentication schemes defined for the API:
## Authorization

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Author

support@formance.com
support@formance.com
support@formance.com
support@formance.com
support@formance.com
support@formance.com
support@formance.com
support@formance.com
support@formance.com
support@formance.com
support@formance.com
support@formance.com
support@formance.com
support@formance.com
support@formance.com
support@formance.com
support@formance.com
support@formance.com

## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in FormanceHQ.apis and FormanceHQ.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from FormanceHQ.apis.default_api import DefaultApi`
- `from FormanceHQ.model.pet import Pet`

Solution 1:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import FormanceHQ
from FormanceHQ.apis import *
from FormanceHQ.models import *
```
